summaryrefslogtreecommitdiff
path: root/kvmd/apps/vnc/server.py
diff options
context:
space:
mode:
Diffstat (limited to 'kvmd/apps/vnc/server.py')
-rw-r--r--kvmd/apps/vnc/server.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/kvmd/apps/vnc/server.py b/kvmd/apps/vnc/server.py
index 57c111ef..4c3d0a55 100644
--- a/kvmd/apps/vnc/server.py
+++ b/kvmd/apps/vnc/server.py
@@ -1,6 +1,6 @@
# ========================================================================== #
# #
# KVMD - The main Pi-KVM daemon. #
# #
# Copyright (C) 2020 Maxim Devaev <[email protected]> #
# #
@@ -68,7 +68,7 @@ from .render import make_text_jpeg
class _SharedParams:
width: int = dataclasses.field(default=800)
height: int = dataclasses.field(default=600)
- name: str = dataclasses.field(default="Pi-KVM")
+ name: str = dataclasses.field(default="PiKVM")
class _Client(RfbClient): # pylint: disable=too-many-instance-attributes
@@ -178,7 +178,7 @@ class _Client(RfbClient): # pylint: disable=too-many-instance-attributes
host = None
else:
if isinstance(host, str):
- name = f"Pi-KVM: {host}"
+ name = f"PiKVM: {host}"
async with self.__lock:
if self._encodings.has_rename:
await self._send_rename(name)
@@ -1,6 +1,6 @@
# ========================================================================== #
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2020 Maxim Devaev <[email protected]> #